@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Template::Resolver;
-$Template::Resolver::VERSION = '1.04';
+$Template::Resolver::VERSION = '1.05';
 # ABSTRACT: A powerful, and simple, library for resolving placeholders in templated files
 # PODNAME: Template::Resolver
 
@@ -103,13 +103,13 @@ Template::Resolver - A powerful, and simple, library for resolving placeholders
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
   use Template::Resolver;
   my $resolver = Template::Resolver->new($entity);
-  $resolver->resolve($file_handle_or_name, $template_prefix);
+  $resolver->resolve(file => '/path/to/file', key => 'REPLACEME');
 
 =head1 DESCRIPTION
 
@@ -133,10 +133,30 @@ The operating system path format used when resolving C<${TEMPLATE_os{xxx}}> plac
 
 =head1 METHODS
 
-=head2 resolve($file_handle_or_name, $placeholder_prefix)
+=head2 resolve(%options)
 
-Will read from C<$file_handle_or_name> replacing all placeholders prefixed by 
-C<$placeholder_prefix>.
+Will read the template and replace all placeholders prefixed by C<key>. One of the 
+options C<content>, C<handle>, or C<filename> is required.  The available options are:
+
+=over 4
+
+=item content
+
+A string containing templated content.
+
+=item filename
+
+The name of a file containing templated content.
+
+=item handle
+
+A handle to a file containing templated content.
+
+=item key
+
+The template key, defaults to C<TEMPLATE>.
+
+=back
 
 =head1 AUTHOR
 
@@ -161,6 +181,10 @@ L<Template::Transformer|Template::Transformer>
 
 =item *
 
+L<Template::Overlay|Template::Overlay>
+
+=item *
+
 L<https://github.com/lucastheisen/template-resolver|https://github.com/lucastheisen/template-resolver>
 
 =back
